This is an abstract bundle of lite tools, follow next to install detail tools:

1. NXP power performance data submitter:

        $ pip install -UI nxp_lite_tools[pp]

2. NXP lf history data submitter:[TODO]

3. NXP NPI dashboard data submitter:[TODO]
